Documentation
¶
Index ¶
- func BenchBasicMemInfo() []benchutil.Bench
- func BenchCPUInfo(n int) []benchutil.Bench
- func BenchMemInfo() []benchutil.Bench
- func BenchMessage(l int) []benchutil.Bench
- func BenchRedditAccount() []benchutil.Bench
- type AccountData
- func (s AccountData) CommentKarma() int64
- func (s AccountData) HasMail() bool
- func (s AccountData) HasModMail() bool
- func (s AccountData) ID() (string, error)
- func (s AccountData) IDBytes() ([]byte, error)
- func (s AccountData) InboxCount() int64
- func (s AccountData) IsFriend() bool
- func (s AccountData) IsGold() bool
- func (s AccountData) LinkKarma() int64
- func (s AccountData) ModHash() (string, error)
- func (s AccountData) ModHashBytes() ([]byte, error)
- func (s AccountData) Name() (string, error)
- func (s AccountData) NameBytes() ([]byte, error)
- func (s AccountData) Over18() bool
- func (s AccountData) SetCommentKarma(v int64)
- func (s AccountData) SetHasMail(v bool)
- func (s AccountData) SetHasModMail(v bool)
- func (s AccountData) SetID(v string) error
- func (s AccountData) SetInboxCount(v int64)
- func (s AccountData) SetIsFriend(v bool)
- func (s AccountData) SetIsGold(v bool)
- func (s AccountData) SetLinkKarma(v int64)
- func (s AccountData) SetModHash(v string) error
- func (s AccountData) SetName(v string) error
- func (s AccountData) SetOver18(v bool)
- type AccountData_List
- type AccountData_Promise
- type BasicMemInfo
- func (s BasicMemInfo) Buffers() int64
- func (s BasicMemInfo) Cached() int64
- func (s BasicMemInfo) MemAvailable() int64
- func (s BasicMemInfo) MemFree() int64
- func (s BasicMemInfo) MemTotal() int64
- func (s BasicMemInfo) SetBuffers(v int64)
- func (s BasicMemInfo) SetCached(v int64)
- func (s BasicMemInfo) SetMemAvailable(v int64)
- func (s BasicMemInfo) SetMemFree(v int64)
- func (s BasicMemInfo) SetMemTotal(v int64)
- func (s BasicMemInfo) SetSwapCached(v int64)
- func (s BasicMemInfo) SetSwapFree(v int64)
- func (s BasicMemInfo) SetSwapTotal(v int64)
- func (s BasicMemInfo) SwapCached() int64
- func (s BasicMemInfo) SwapFree() int64
- func (s BasicMemInfo) SwapTotal() int64
- type BasicMemInfo_List
- type BasicMemInfo_Promise
- type CPU
- func (s CPU) AddressSizes() (string, error)
- func (s CPU) AddressSizesBytes() ([]byte, error)
- func (s CPU) ApicID() int16
- func (s CPU) BogoMIPS() float32
- func (s CPU) CLFlushSize() (string, error)
- func (s CPU) CLFlushSizeBytes() ([]byte, error)
- func (s CPU) CPUCores() int16
- func (s CPU) CPUFamily() (string, error)
- func (s CPU) CPUFamilyBytes() ([]byte, error)
- func (s CPU) CPUIDLevel() (string, error)
- func (s CPU) CPUIDLevelBytes() ([]byte, error)
- func (s CPU) CPUMHz() float32
- func (s CPU) CacheAlignment() (string, error)
- func (s CPU) CacheAlignmentBytes() ([]byte, error)
- func (s CPU) CacheSize() (string, error)
- func (s CPU) CacheSizeBytes() ([]byte, error)
- func (s CPU) CoreID() int16
- func (s CPU) FPU() (string, error)
- func (s CPU) FPUBytes() ([]byte, error)
- func (s CPU) FPUException() (string, error)
- func (s CPU) FPUExceptionBytes() ([]byte, error)
- func (s CPU) Flags() (string, error)
- func (s CPU) FlagsBytes() ([]byte, error)
- func (s CPU) InitialApicID() int16
- func (s CPU) Microcode() (string, error)
- func (s CPU) MicrocodeBytes() ([]byte, error)
- func (s CPU) Model() (string, error)
- func (s CPU) ModelBytes() ([]byte, error)
- func (s CPU) ModelName() (string, error)
- func (s CPU) ModelNameBytes() ([]byte, error)
- func (s CPU) PhysicalID() int16
- func (s CPU) PowerManagement() (string, error)
- func (s CPU) PowerManagementBytes() ([]byte, error)
- func (s CPU) Processor() int16
- func (s CPU) SetAddressSizes(v string) error
- func (s CPU) SetApicID(v int16)
- func (s CPU) SetBogoMIPS(v float32)
- func (s CPU) SetCLFlushSize(v string) error
- func (s CPU) SetCPUCores(v int16)
- func (s CPU) SetCPUFamily(v string) error
- func (s CPU) SetCPUIDLevel(v string) error
- func (s CPU) SetCPUMHz(v float32)
- func (s CPU) SetCacheAlignment(v string) error
- func (s CPU) SetCacheSize(v string) error
- func (s CPU) SetCoreID(v int16)
- func (s CPU) SetFPU(v string) error
- func (s CPU) SetFPUException(v string) error
- func (s CPU) SetFlags(v string) error
- func (s CPU) SetInitialApicID(v int16)
- func (s CPU) SetMicrocode(v string) error
- func (s CPU) SetModel(v string) error
- func (s CPU) SetModelName(v string) error
- func (s CPU) SetPhysicalID(v int16)
- func (s CPU) SetPowerManagement(v string) error
- func (s CPU) SetProcessor(v int16)
- func (s CPU) SetSiblings(v int16)
- func (s CPU) SetStepping(v string) error
- func (s CPU) SetVendorID(v string) error
- func (s CPU) SetWP(v string) error
- func (s CPU) Siblings() int16
- func (s CPU) Stepping() (string, error)
- func (s CPU) SteppingBytes() ([]byte, error)
- func (s CPU) VendorID() (string, error)
- func (s CPU) VendorIDBytes() ([]byte, error)
- func (s CPU) WP() (string, error)
- func (s CPU) WPBytes() ([]byte, error)
- type CPUInfo
- type CPUInfo_List
- type CPUInfo_Promise
- type CPU_List
- type CPU_Promise
- type MemInfo
- func (s MemInfo) Active() int64
- func (s MemInfo) ActiveAnon() int64
- func (s MemInfo) ActiveFile() int64
- func (s MemInfo) AnonHugePages() int64
- func (s MemInfo) AnonPages() int64
- func (s MemInfo) Bounce() int64
- func (s MemInfo) Buffers() int64
- func (s MemInfo) Cached() int64
- func (s MemInfo) CommitLimit() int64
- func (s MemInfo) DirectMap2M() int64
- func (s MemInfo) DirectMap4k() int64
- func (s MemInfo) Dirty() int64
- func (s MemInfo) HardwareCorrupted() int64
- func (s MemInfo) HugePagesFree() int64
- func (s MemInfo) HugePagesRsvd() int64
- func (s MemInfo) HugePagesTotal() int64
- func (s MemInfo) Hugepagesize() int64
- func (s MemInfo) Inactive() int64
- func (s MemInfo) InactiveAnon() int64
- func (s MemInfo) InactiveFile() int64
- func (s MemInfo) KernelStack() int64
- func (s MemInfo) Mapped() int64
- func (s MemInfo) MemAvailable() int64
- func (s MemInfo) MemFree() int64
- func (s MemInfo) MemTotal() int64
- func (s MemInfo) Mlocked() int64
- func (s MemInfo) NFSUnstable() int64
- func (s MemInfo) SReclaimable() int64
- func (s MemInfo) SUnreclaim() int64
- func (s MemInfo) SetActive(v int64)
- func (s MemInfo) SetActiveAnon(v int64)
- func (s MemInfo) SetActiveFile(v int64)
- func (s MemInfo) SetAnonHugePages(v int64)
- func (s MemInfo) SetAnonPages(v int64)
- func (s MemInfo) SetBounce(v int64)
- func (s MemInfo) SetBuffers(v int64)
- func (s MemInfo) SetCached(v int64)
- func (s MemInfo) SetCommitLimit(v int64)
- func (s MemInfo) SetDirectMap2M(v int64)
- func (s MemInfo) SetDirectMap4k(v int64)
- func (s MemInfo) SetDirty(v int64)
- func (s MemInfo) SetHardwareCorrupted(v int64)
- func (s MemInfo) SetHugePagesFree(v int64)
- func (s MemInfo) SetHugePagesRsvd(v int64)
- func (s MemInfo) SetHugePagesTotal(v int64)
- func (s MemInfo) SetHugepagesize(v int64)
- func (s MemInfo) SetInactive(v int64)
- func (s MemInfo) SetInactiveAnon(v int64)
- func (s MemInfo) SetInactiveFile(v int64)
- func (s MemInfo) SetKernelStack(v int64)
- func (s MemInfo) SetMapped(v int64)
- func (s MemInfo) SetMemAvailable(v int64)
- func (s MemInfo) SetMemFree(v int64)
- func (s MemInfo) SetMemTotal(v int64)
- func (s MemInfo) SetMlocked(v int64)
- func (s MemInfo) SetNFSUnstable(v int64)
- func (s MemInfo) SetSReclaimable(v int64)
- func (s MemInfo) SetSUnreclaim(v int64)
- func (s MemInfo) SetShmem(v int64)
- func (s MemInfo) SetSlab(v int64)
- func (s MemInfo) SetSwapCached(v int64)
- func (s MemInfo) SetSwapFree(v int64)
- func (s MemInfo) SetSwapTotal(v int64)
- func (s MemInfo) SetUnevictable(v int64)
- func (s MemInfo) SetVmallocChunk(v int64)
- func (s MemInfo) SetVmallocTotal(v int64)
- func (s MemInfo) SetVmallocUsed(v int64)
- func (s MemInfo) SetWriteback(v int64)
- func (s MemInfo) SetWritebackTmp(v int64)
- func (s MemInfo) Shmem() int64
- func (s MemInfo) Slab() int64
- func (s MemInfo) SwapCached() int64
- func (s MemInfo) SwapFree() int64
- func (s MemInfo) SwapTotal() int64
- func (s MemInfo) Unevictable() int64
- func (s MemInfo) VmallocChunk() int64
- func (s MemInfo) VmallocTotal() int64
- func (s MemInfo) VmallocUsed() int64
- func (s MemInfo) Writeback() int64
- func (s MemInfo) WritebackTmp() int64
- type MemInfo_List
- type MemInfo_Promise
- type Message
- func (s Message) Data() ([]byte, error)
- func (s Message) DestID() uint32
- func (s Message) ID() ([]byte, error)
- func (s Message) Kind() int16
- func (s Message) SetData(v []byte) error
- func (s Message) SetDestID(v uint32)
- func (s Message) SetID(v []byte) error
- func (s Message) SetKind(v int16)
- func (s Message) SetType(v int8)
- func (s Message) Type() int8
- type Message_List
- type Message_Promise
- type RedditAccount
- func (s RedditAccount) Data() (AccountData, error)
- func (s RedditAccount) ID() (string, error)
- func (s RedditAccount) IDBytes() ([]byte, error)
- func (s RedditAccount) Kind() (string, error)
- func (s RedditAccount) KindBytes() ([]byte, error)
- func (s RedditAccount) Name() (string, error)
- func (s RedditAccount) NameBytes() ([]byte, error)
- func (s RedditAccount) NewData() (AccountData, error)
- func (s RedditAccount) SetData(v AccountData) error
- func (s RedditAccount) SetID(v string) error
- func (s RedditAccount) SetKind(v string) error
- func (s RedditAccount) SetName(v string) error
- type RedditAccount_List
- type RedditAccount_Promise
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BenchBasicMemInfo ¶
BenchBasicMemInfo runs the BasicMemInfo benches for Marshal/Unmarshal.
func BenchCPUInfo ¶
BenchCPUInfo runs the CPUInfo benches for Marshal/Unmarshal.
func BenchMemInfo ¶
BenchMemInfo runs the MemInfo benches for Marshal/Unmarshal.
func BenchMessage ¶
BenchMessage runs the Message benches for Marshal/Unmarshal.
func BenchRedditAccount ¶
BenchRedditAccount runs the RedditAccount benches for Marshal/Unmarshal.
Types ¶
type AccountData ¶
func NewAccountData ¶
func NewAccountData(s *capnp.Segment) (AccountData, error)
func NewRootAccountData ¶
func NewRootAccountData(s *capnp.Segment) (AccountData, error)
func ReadRootAccountData ¶
func ReadRootAccountData(msg *capnp.Message) (AccountData, error)
func (AccountData) CommentKarma ¶
func (s AccountData) CommentKarma() int64
func (AccountData) HasMail ¶
func (s AccountData) HasMail() bool
func (AccountData) HasModMail ¶
func (s AccountData) HasModMail() bool
func (AccountData) ID ¶
func (s AccountData) ID() (string, error)
func (AccountData) IDBytes ¶
func (s AccountData) IDBytes() ([]byte, error)
func (AccountData) InboxCount ¶
func (s AccountData) InboxCount() int64
func (AccountData) IsFriend ¶
func (s AccountData) IsFriend() bool
func (AccountData) IsGold ¶
func (s AccountData) IsGold() bool
func (AccountData) LinkKarma ¶
func (s AccountData) LinkKarma() int64
func (AccountData) ModHash ¶
func (s AccountData) ModHash() (string, error)
func (AccountData) ModHashBytes ¶
func (s AccountData) ModHashBytes() ([]byte, error)
func (AccountData) Name ¶
func (s AccountData) Name() (string, error)
func (AccountData) NameBytes ¶
func (s AccountData) NameBytes() ([]byte, error)
func (AccountData) Over18 ¶
func (s AccountData) Over18() bool
func (AccountData) SetCommentKarma ¶
func (s AccountData) SetCommentKarma(v int64)
func (AccountData) SetHasMail ¶
func (s AccountData) SetHasMail(v bool)
func (AccountData) SetHasModMail ¶
func (s AccountData) SetHasModMail(v bool)
func (AccountData) SetID ¶
func (s AccountData) SetID(v string) error
func (AccountData) SetInboxCount ¶
func (s AccountData) SetInboxCount(v int64)
func (AccountData) SetIsFriend ¶
func (s AccountData) SetIsFriend(v bool)
func (AccountData) SetIsGold ¶
func (s AccountData) SetIsGold(v bool)
func (AccountData) SetLinkKarma ¶
func (s AccountData) SetLinkKarma(v int64)
func (AccountData) SetModHash ¶
func (s AccountData) SetModHash(v string) error
func (AccountData) SetName ¶
func (s AccountData) SetName(v string) error
func (AccountData) SetOver18 ¶
func (s AccountData) SetOver18(v bool)
type AccountData_List ¶
AccountData_List is a list of AccountData.
func NewAccountData_List ¶
func NewAccountData_List(s *capnp.Segment, sz int32) (AccountData_List, error)
NewAccountData creates a new list of AccountData.
func (AccountData_List) At ¶
func (s AccountData_List) At(i int) AccountData
func (AccountData_List) Set ¶
func (s AccountData_List) Set(i int, v AccountData) error
type AccountData_Promise ¶
AccountData_Promise is a wrapper for a AccountData promised by a client call.
func (AccountData_Promise) Struct ¶
func (p AccountData_Promise) Struct() (AccountData, error)
type BasicMemInfo ¶
func NewBasicMemInfo ¶
func NewBasicMemInfo(s *capnp.Segment) (BasicMemInfo, error)
func NewRootBasicMemInfo ¶
func NewRootBasicMemInfo(s *capnp.Segment) (BasicMemInfo, error)
func ReadRootBasicMemInfo ¶
func ReadRootBasicMemInfo(msg *capnp.Message) (BasicMemInfo, error)
func (BasicMemInfo) Buffers ¶
func (s BasicMemInfo) Buffers() int64
func (BasicMemInfo) Cached ¶
func (s BasicMemInfo) Cached() int64
func (BasicMemInfo) MemAvailable ¶
func (s BasicMemInfo) MemAvailable() int64
func (BasicMemInfo) MemFree ¶
func (s BasicMemInfo) MemFree() int64
func (BasicMemInfo) MemTotal ¶
func (s BasicMemInfo) MemTotal() int64
func (BasicMemInfo) SetBuffers ¶
func (s BasicMemInfo) SetBuffers(v int64)
func (BasicMemInfo) SetCached ¶
func (s BasicMemInfo) SetCached(v int64)
func (BasicMemInfo) SetMemAvailable ¶
func (s BasicMemInfo) SetMemAvailable(v int64)
func (BasicMemInfo) SetMemFree ¶
func (s BasicMemInfo) SetMemFree(v int64)
func (BasicMemInfo) SetMemTotal ¶
func (s BasicMemInfo) SetMemTotal(v int64)
func (BasicMemInfo) SetSwapCached ¶
func (s BasicMemInfo) SetSwapCached(v int64)
func (BasicMemInfo) SetSwapFree ¶
func (s BasicMemInfo) SetSwapFree(v int64)
func (BasicMemInfo) SetSwapTotal ¶
func (s BasicMemInfo) SetSwapTotal(v int64)
func (BasicMemInfo) SwapCached ¶
func (s BasicMemInfo) SwapCached() int64
func (BasicMemInfo) SwapFree ¶
func (s BasicMemInfo) SwapFree() int64
func (BasicMemInfo) SwapTotal ¶
func (s BasicMemInfo) SwapTotal() int64
type BasicMemInfo_List ¶
BasicMemInfo_List is a list of BasicMemInfo.
func NewBasicMemInfo_List ¶
func NewBasicMemInfo_List(s *capnp.Segment, sz int32) (BasicMemInfo_List, error)
NewBasicMemInfo creates a new list of BasicMemInfo.
func (BasicMemInfo_List) At ¶
func (s BasicMemInfo_List) At(i int) BasicMemInfo
func (BasicMemInfo_List) Set ¶
func (s BasicMemInfo_List) Set(i int, v BasicMemInfo) error
type BasicMemInfo_Promise ¶
BasicMemInfo_Promise is a wrapper for a BasicMemInfo promised by a client call.
func (BasicMemInfo_Promise) Struct ¶
func (p BasicMemInfo_Promise) Struct() (BasicMemInfo, error)
type CPU ¶
func (CPU) AddressSizes ¶
func (CPU) AddressSizesBytes ¶
func (CPU) CLFlushSize ¶
func (CPU) CLFlushSizeBytes ¶
func (CPU) CPUFamilyBytes ¶
func (CPU) CPUIDLevel ¶
func (CPU) CPUIDLevelBytes ¶
func (CPU) CacheAlignment ¶
func (CPU) CacheAlignmentBytes ¶
func (CPU) CacheSizeBytes ¶
func (CPU) FPUException ¶
func (CPU) FPUExceptionBytes ¶
func (CPU) FlagsBytes ¶
func (CPU) InitialApicID ¶
func (CPU) MicrocodeBytes ¶
func (CPU) ModelBytes ¶
func (CPU) ModelNameBytes ¶
func (CPU) PhysicalID ¶
func (CPU) PowerManagement ¶
func (CPU) PowerManagementBytes ¶
func (CPU) SetAddressSizes ¶
func (CPU) SetBogoMIPS ¶
func (CPU) SetCLFlushSize ¶
func (CPU) SetCPUCores ¶
func (CPU) SetCPUFamily ¶
func (CPU) SetCPUIDLevel ¶
func (CPU) SetCacheAlignment ¶
func (CPU) SetCacheSize ¶
func (CPU) SetFPUException ¶
func (CPU) SetInitialApicID ¶
func (CPU) SetMicrocode ¶
func (CPU) SetModelName ¶
func (CPU) SetPhysicalID ¶
func (CPU) SetPowerManagement ¶
func (CPU) SetProcessor ¶
func (CPU) SetSiblings ¶
func (CPU) SetStepping ¶
func (CPU) SetVendorID ¶
func (CPU) SteppingBytes ¶
func (CPU) VendorIDBytes ¶
type CPUInfo_List ¶
CPUInfo_List is a list of CPUInfo.
func NewCPUInfo_List ¶
func NewCPUInfo_List(s *capnp.Segment, sz int32) (CPUInfo_List, error)
NewCPUInfo creates a new list of CPUInfo.
func (CPUInfo_List) At ¶
func (s CPUInfo_List) At(i int) CPUInfo
type CPUInfo_Promise ¶
CPUInfo_Promise is a wrapper for a CPUInfo promised by a client call.
func (CPUInfo_Promise) Struct ¶
func (p CPUInfo_Promise) Struct() (CPUInfo, error)
type CPU_Promise ¶
CPU_Promise is a wrapper for a CPU promised by a client call.
func (CPU_Promise) Struct ¶
func (p CPU_Promise) Struct() (CPU, error)
type MemInfo ¶
func (MemInfo) ActiveAnon ¶
func (MemInfo) ActiveFile ¶
func (MemInfo) AnonHugePages ¶
func (MemInfo) CommitLimit ¶
func (MemInfo) DirectMap2M ¶
func (MemInfo) DirectMap4k ¶
func (MemInfo) HardwareCorrupted ¶
func (MemInfo) HugePagesFree ¶
func (MemInfo) HugePagesRsvd ¶
func (MemInfo) HugePagesTotal ¶
func (MemInfo) Hugepagesize ¶
func (MemInfo) InactiveAnon ¶
func (MemInfo) InactiveFile ¶
func (MemInfo) KernelStack ¶
func (MemInfo) MemAvailable ¶
func (MemInfo) NFSUnstable ¶
func (MemInfo) SReclaimable ¶
func (MemInfo) SUnreclaim ¶
func (MemInfo) SetActiveAnon ¶
func (MemInfo) SetActiveFile ¶
func (MemInfo) SetAnonHugePages ¶
func (MemInfo) SetAnonPages ¶
func (MemInfo) SetBuffers ¶
func (MemInfo) SetCommitLimit ¶
func (MemInfo) SetDirectMap2M ¶
func (MemInfo) SetDirectMap4k ¶
func (MemInfo) SetHardwareCorrupted ¶
func (MemInfo) SetHugePagesFree ¶
func (MemInfo) SetHugePagesRsvd ¶
func (MemInfo) SetHugePagesTotal ¶
func (MemInfo) SetHugepagesize ¶
func (MemInfo) SetInactive ¶
func (MemInfo) SetInactiveAnon ¶
func (MemInfo) SetInactiveFile ¶
func (MemInfo) SetKernelStack ¶
func (MemInfo) SetMemAvailable ¶
func (MemInfo) SetMemFree ¶
func (MemInfo) SetMemTotal ¶
func (MemInfo) SetMlocked ¶
func (MemInfo) SetNFSUnstable ¶
func (MemInfo) SetSReclaimable ¶
func (MemInfo) SetSUnreclaim ¶
func (MemInfo) SetSwapCached ¶
func (MemInfo) SetSwapFree ¶
func (MemInfo) SetSwapTotal ¶
func (MemInfo) SetUnevictable ¶
func (MemInfo) SetVmallocChunk ¶
func (MemInfo) SetVmallocTotal ¶
func (MemInfo) SetVmallocUsed ¶
func (MemInfo) SetWriteback ¶
func (MemInfo) SetWritebackTmp ¶
func (MemInfo) SwapCached ¶
func (MemInfo) Unevictable ¶
func (MemInfo) VmallocChunk ¶
func (MemInfo) VmallocTotal ¶
func (MemInfo) VmallocUsed ¶
func (MemInfo) WritebackTmp ¶
type MemInfo_List ¶
MemInfo_List is a list of MemInfo.
func NewMemInfo_List ¶
func NewMemInfo_List(s *capnp.Segment, sz int32) (MemInfo_List, error)
NewMemInfo creates a new list of MemInfo.
func (MemInfo_List) At ¶
func (s MemInfo_List) At(i int) MemInfo
type MemInfo_Promise ¶
MemInfo_Promise is a wrapper for a MemInfo promised by a client call.
func (MemInfo_Promise) Struct ¶
func (p MemInfo_Promise) Struct() (MemInfo, error)
type Message_List ¶
Message_List is a list of Message.
func NewMessage_List ¶
func NewMessage_List(s *capnp.Segment, sz int32) (Message_List, error)
NewMessage creates a new list of Message.
func (Message_List) At ¶
func (s Message_List) At(i int) Message
type Message_Promise ¶
Message_Promise is a wrapper for a Message promised by a client call.
func (Message_Promise) Struct ¶
func (p Message_Promise) Struct() (Message, error)
type RedditAccount ¶
func NewRedditAccount ¶
func NewRedditAccount(s *capnp.Segment) (RedditAccount, error)
func NewRootRedditAccount ¶
func NewRootRedditAccount(s *capnp.Segment) (RedditAccount, error)
func ReadRootRedditAccount ¶
func ReadRootRedditAccount(msg *capnp.Message) (RedditAccount, error)
func (RedditAccount) Data ¶
func (s RedditAccount) Data() (AccountData, error)
func (RedditAccount) ID ¶
func (s RedditAccount) ID() (string, error)
func (RedditAccount) IDBytes ¶
func (s RedditAccount) IDBytes() ([]byte, error)
func (RedditAccount) Kind ¶
func (s RedditAccount) Kind() (string, error)
func (RedditAccount) KindBytes ¶
func (s RedditAccount) KindBytes() ([]byte, error)
func (RedditAccount) Name ¶
func (s RedditAccount) Name() (string, error)
func (RedditAccount) NameBytes ¶
func (s RedditAccount) NameBytes() ([]byte, error)
func (RedditAccount) NewData ¶
func (s RedditAccount) NewData() (AccountData, error)
NewData sets the data field to a newly allocated AccountData struct, preferring placement in s's segment.
func (RedditAccount) SetData ¶
func (s RedditAccount) SetData(v AccountData) error
func (RedditAccount) SetID ¶
func (s RedditAccount) SetID(v string) error
func (RedditAccount) SetKind ¶
func (s RedditAccount) SetKind(v string) error
func (RedditAccount) SetName ¶
func (s RedditAccount) SetName(v string) error
type RedditAccount_List ¶
RedditAccount_List is a list of RedditAccount.
func NewRedditAccount_List ¶
func NewRedditAccount_List(s *capnp.Segment, sz int32) (RedditAccount_List, error)
NewRedditAccount creates a new list of RedditAccount.
func (RedditAccount_List) At ¶
func (s RedditAccount_List) At(i int) RedditAccount
func (RedditAccount_List) Set ¶
func (s RedditAccount_List) Set(i int, v RedditAccount) error
type RedditAccount_Promise ¶
RedditAccount_Promise is a wrapper for a RedditAccount promised by a client call.
func (RedditAccount_Promise) Data ¶
func (p RedditAccount_Promise) Data() AccountData_Promise
func (RedditAccount_Promise) Struct ¶
func (p RedditAccount_Promise) Struct() (RedditAccount, error)